inbreeding <- function( N=50, f=0.5, stoptime=500, init.A=0.5, batch=1 ) {
   eps <- 1e-8

   # check N
   if ( N <= 0 )
      stop( "N must be greater than 0" )

   # check f
   if ( f < 0 || f > 1 )
      stop( "f must be between 0 and 1" )

   # check init.A
   if ( init.A < 0 || init.A > 1 )
      stop( "init.A must be between 0 and 1" )

   # check stoptime
   if ( stoptime <= 0 )
      stop( "stoptime must be greater than 0" )

   # check batch
   if ( batch <= 0 )
      stop( "batch must be greater than 0" )

   
   nn         <- 2*N
   NumInbr    <- f*N
   NumNotInbr <- N - NumInbr
   init.fixed <- ifelse( init.A == 0 || init.A == 1, TRUE, FALSE )

   m.freq.A   <- vector( )
   m.freq.a   <- vector( )
   m.fixed    <- vector( )

   for ( run in 1:batch ) {
      freq.A     <- init.A
      fixed      <- init.fixed

      for ( i in 1:stoptime ) {
         InbrA    <- 2 * rbinom( 1, NumInbr, freq.A[i] )
         NotInbrA <- rbinom( 1, 2*NumNotInbr, freq.A[i] )

         newFreq  <- (InbrA + NotInbrA) / nn
         freq.A   <- c( freq.A, newFreq )
      }

      fixed    <- ifelse( freq.A == 0 | freq.A == 1, TRUE, FALSE )
     
      m.freq.A <- cbind( m.freq.A, freq.A )
      m.freq.a <- cbind( m.freq.a, 1-freq.A )
      m.fixed  <- cbind( m.fixed, fixed )
   }

   ret <- list( "freq.A"=m.freq.A, "freq.a"=m.freq.a, "fixed"=m.fixed )
   class( ret ) <- "inbreeding"
   
   return( ret )
}

plot.inbreeding <- function( x, what=c( "freq.A" ), col=vector(), 
                             xlim=NULL, ylim = c( 0, 1 ), 
                             xlab="time", ylab="freq", 
                             legend.pos="bottomright", ... )
{
   stoptime <- nrow( x$freq.A ) - 1

   legend <- vector()
   legend.col <- vector()
   
   col["freq.A"] <- ifelse( is.na( col["freq.A"] ), "red",   col["freq.A"] )
   col["freq.a"] <- ifelse( is.na( col["freq.a"] ), "green", col["freq.A"] )
   col["fixed"]  <- ifelse( is.na( col["fixed"] ),  "blue",  col["fixed"] )

   if ( is.null( xlim ) ) {
     xlim <- c( 0, stoptime )
   }
   
   plot( 0, 0, xlim=xlim, ylim=ylim, type="n",
         xlab=xlab, ylab=ylab, ... )
   
   if ( "freq.A" %in% what ) {
      lines( 0:stoptime, apply( x$freq.A, 1, mean ), col=col["freq.A"] )
      legend <- c( legend, "freq.A" )
      legend.col <- c( legend.col, col["freq.A"] )
   }

   if ( "freq.a" %in% what ) {
      lines( 0:stoptime, apply( x$freq.a, 1, mean ), col=col["freq.a"] )
      legend <- c( legend, "freq.a" )
      legend.col <- c( legend.col, col["freq.a"] )
   }

   if ( "fixed" %in% what ) {
      lines( 0:stoptime, apply( x$fixed, 1, mean ), col=col["fixed"] )
      legend <- c( legend, "fixed" )
      legend.col <- c( legend.col, col["fixed"] )
   }

   legend( legend.pos, legend=legend,
           col=legend.col, lty=1, bg="white" )
}
