\name{maint}

\alias{maint}
\alias{maintenance}

\alias{plot.maintenance}

\title{Maintenance of Heterocygosity}
\description{Simulation of maintenance of heterocygosity}

\usage{
maint( N=100, u=0.001, stoptime=10, 
       init.A=1, init.C=0, init.G=0, init.T=0 )

\method{plot}{maintenance}( x, what=c( "A", "C", "G", "T" ), col=vector(), 
      xlim=NULL, ylim=NULL, xlab="time", ylab="freq", 
      legend.pos="bottomright", ... )
}

\arguments{
   \item{x}{object of class \code{maintenance}}
   \item{N}{number of individuals}
   \item{u}{mutation rate}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{init.A}{initial frequency of A}
   \item{init.C}{initial frequency of C}
   \item{init.G}{initial frequency of G}
   \item{init.T}{initial frequency of T}
   \item{what}{which curves to show (possible: "A", "C", "G", "T", "h",
                                               "h.pred", "numOfMut", "fixed" )}
   \item{col}{named vector with colors for each curve defined in \code{what}}
   \item{xlim}{range of x axis; default: 0 to stoptime}
   \item{ylim}{range of y axis; default: 0 to 1}
   \item{xlab}{annotation of x axis}
   \item{ylab}{annotation of y axis}
   \item{legend.pos}{position of legend. See Details}
   \item{\dots}{additional arguments}
}

\details{
A four alleles model is assumed. If there is a mutation and a new allele enters the population is decided by a random number between 0 and 1. A second random number determines whether this mutation will be an A, C, T or G. The frequencies of the alleles are randomly chosen from a multinomial distribution. In a generation in which a mutation happens, there are just n-1 individuals that get an allele assigned and the one individual gets the allele that was determined by the second random number. It is taken care that the pop size stays constant. Only one mutation per generation in the population is allowed. So a mutation occurs if the first dummy is below u*n, which gives a population wide mutation rate of u*n.

The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{maintenance}, a list with elements
\item{freq}{a matrix of the allele frequencies per generation}
\item{h}{heterozygosity per generation}
\item{h.pred}{}
\item{numOfMut}{number of mutations that occured until now}
\item{fixed}{number of mutations that fixated until now}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
ret <- maint( stoptime=1000, init.A=0.8, init.C=0.2 )

plot( ret )
plot( ret, col=c( "C"="orange" ) )
plot( ret, what=c( "A", "C", "G", "T", "h" ) )

plot( ret, what=c( "h" ) )
plot( maint(), what=c( "h", "h.pred" ) )

plot( maint(), what=c( "numOfMut", "fixed" ), ylim=c(0,10) )
}

\keyword{distribution}
