\name{mullersRatchet}

\alias{mullersRatchet}

\alias{plot.mullersRatchet}

\title{Muller's Ratchet}
\description{Simulation of Muller's Ratchet}

\usage{
mullersRatchet( u=0.1, s=0.05, init.freq=c(1), stoptime=50, n.class=20 )

\method{plot}{mullersRatchet}( x, gen, what=c( "freq", "dpois" ), col=vector(), 
      xlim=NULL, ylim=NULL, xlab="no. of mutations", ylab="frequency", 
      legend.pos="topright", ... )
}

\arguments{
   \item{x}{object of class \code{mullersRatchet}}
   \item{u}{mutation rate}
   \item{s}{selection coefficient of a deleterious mutation}
   \item{init.freq}{initial frequencies for the first classes; does not have to sum up to 1}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{n.class}{number of classes considered in the simulation}
   \item{gen}{which generation to show; from 1 to stoptime}
   \item{what}{which curves to show (possible: "fit", "freq", "dpois")}
   \item{col}{named vector with colors for each curve defined in \code{what}}
   \item{xlim}{range of x axis; default: 0 to (n.classes -1 )}
   \item{ylim}{range of y axis; default: 0 to max of possible y values}
   \item{xlab}{annotation of x axis}
   \item{ylab}{annotation of y axis}
   \item{legend.pos}{position of legend. See Details}
   \item{\dots}{additional arguments}
}

\details{
 \code{mullersRatchet()} shows, how the equilibrium distribution of deleterious alleles is approached.

The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{mullersRatchet}, a list with elements
\item{u}{mutation rate}
\item{s}{selection coefficient of a deleterious mutation}
\item{fit}{a vector containing the fitness of each class at the end of the simulation, i.e. at generation \code{stoptime}.}
\item{freq}{a vector containing the frequencies of each class at the end of the simulation, i.e. at generation \code{stoptime}.}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
# What do the first 20 classes in Mullers ratchet look like after 
# 100 generations if u=0.1 and s=0.05?

n.class <- 20

fit.100 <- mullersRatchet( u=0.1, s=0.05, init.freq=1, n.class=20, 
                           stoptime=100 )

plot( fit.100)
}

\keyword{distribution}
