\name{selectionDet}

\alias{selectionDet}
\alias{selection}

\alias{plot.selectionDet}
\alias{plot.selectionWF}
\alias{plot.selection}

\title{Selection}
\description{Selection in deterministic models}

\usage{
selectionDet( init.A=0.05, s=0.01, h=0.5, stoptime=2000 )

\method{plot}{selection}( x, what=c( "freq.A", "w.bar" ), 
      col=vector(), xlim=NULL, ylim=c( 0, 1 ), xlab="time", 
      ylab="freq", legend.pos="bottomright", ... )
}

\arguments{
   \item{init.A}{initial frequency of allele A}
   \item{s}{selection coefficient}
   \item{h}{dominance coefficient}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{x}{object of class \code{selectionDet}}
   \item{what}{which curves to show (possible: "freq.A", "freq.a", 
                                               "freq.A.prime", "w.bar",
                                               "fixed" )}
   \item{col}{named vector with colors for each curve defined in \code{what}}
   \item{xlim}{range of x axis; default: 0 to stoptime}
   \item{ylim}{range of y axis; default: 0 to 1}
   \item{xlab}{annotation of x axis}
   \item{ylab}{annotation of y axis}
   \item{legend.pos}{position of legend. See Details}
   \item{\dots}{additional arguments}
}

\details{
\code{selectionDet()} implements a deterministic model with selection and fitnesses 1, 1-sh and 1-s. It implements the solution of the following differential equation: \deqn{\frac{dp}{dt} = sp(1-p)\frac{1-h+p(2h-1)}{\bar{w}}}{dp/dt = sp(1-p)(1-h+p(2h-1))/w.bar} where \deqn{\bar{w} = p^2 + 2(1-sh)p(1-p) + (1-s)(1-p)^2}{w.bar = p^2 + 2(1-sh)p(1-p) + (1-s)(1-p)^2}.
   
The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{selectionDet}, a list with elements
\item{freq.A}{the allele frequencies of allele A per generation}
\item{freq.a}{the allele frequencies of allele a per generation}
\item{freq.A}{the values of the derivation per generation}
\item{w.bar}{the mean fitness per generation}
\item{fixed}{logical values indicating whether an allele has come to fixation}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
ret <- selectionDet( init.A=0.1, s=0.2, h=0.2, stoptime=400 )

plot( ret )
plot( ret, what=c( "freq.A", "w.bar" ), 
           col=c( "freq.A"="black", "w.bar"="blue" ) )
plot( ret, what=c( "freq.A.prime" ) )
}

\keyword{distribution}
