\name{wf.freq}

\alias{wf.freq}

\title{Selection}
\description{Frequencies in the Wright-Fisher model}

\usage{
wf.freq( N=500, init.A=0.001, s=0, h=0.5, uA2a=0, ua2A=0, 
         stoptime=500, batch=1 )
}

\arguments{
   \item{N}{number of individuals}
   \item{init.A}{initial frequency of allele A}
   \item{s}{selective advantage of AA against aa}
   \item{h}{dominance coefficient}
   \item{uA2a}{mutation rate from allele A to allele a}
   \item{ua2A}{mutation rate from allele a to allele A}
   \item{stoptime}{stoptime i.e. the number of generations to simulate}
   \item{batch}{number of batch runs}
}

\details{
\code{selectionWF()} implements the Wright-Fisher model with selection and fitnesses 1, 1-sh and 1-s.
The location of the legend can be specified by setting 'legend.pos' to a single keyword from the list '"bottomright"', '"bottom"', '"bottomleft"', '"left"', '"topleft"', '"top"', '"topright"', '"right"' and '"center"'. This places the legend on the inside of the plot frame at the given location.
}

\value{
An object of class \code{selectionWF}, a list with elements
\item{freq.A}{a matrix of the allele frequencies of allele A per generation per batch run}
\item{freq.a}{a matrix of the allele frequencies of allele a per generation per batch run}
\item{w.bar}{a matrix of the mean fitness per generation per batch run}
\item{fixed}{a matrix of logical values indicating whether an allele has come to fixation}
}

\references{\url{http://www.zi.biologie.uni-muenchen.de/~pfaffelhuber/teaching/popgenCourse.html}}
\author{Ulrike Feldmann}

\examples{
ret <- wf.freq( N=1000, init.A=0.01, stoptime=200 )

plot( ret )
plot( ret, what=c( "freq.A", "freq.a" ), 
           col=c( "freq.A"="black", "freq.a"="blue" ) )
   
# batch runs
ret <- wf.freq( N=100, stoptime=200, batch=100 )

plot( ret, what=c( "w.bar", "fixed" ) )
}

\keyword{distribution}
